@@ -14,13 +14,13 @@ class APIFunction(LambdaFunction):
 
         # TODO: Should use a more elegent method of routing here.
         if method == "post":
-            response = self.post(event, *args)
+            response = self.post(event, context, *args)
 
         elif method == "get":
-            response = self.get(event, *args)
+            response = self.get(event, context, *args)
 
         elif method == "put":
-            response = self.put(event, *args)
+            response = self.put(event, context, *args)
 
         elif method == "options":
             response = self.create_return()
@@ -34,8 +34,8 @@ class APIFunction(LambdaFunction):
         return_obj = {"statusCode": status_code}
         headers = {
             "Access-Control-Allow-Origin": "*",
-            "Access-Control-Allow-Credentials": "true",
-            "Access-Control-Allow-Headers": "Content-Type",
+            # "Access-Control-Allow-Credentials": "true",
+            "Access-Control-Allow-Headers": "*",
             "Access-Control-Allow-Methods": "*",
         }
         return_obj["headers"] = headers
